# pyxart
Python implementation of Asynchronous Ratchet Trees

# references

- https://research.facebook.com/publications/on-ends-to-ends-encryption-asynchronous-group-messaging-with-strong-security-guarantees/